<?php
session_start();
include("../db/db.php");

if ($_SERVER['REQUEST_METHOD'] == "POST") {
    $drop = isset($_REQUEST['drop']) ? $_REQUEST['drop'] : null;
    $carType = isset($_REQUEST['carType']) ? $_REQUEST['carType'] : null;
    $pickup = isset($_REQUEST['pickup']) ? $_REQUEST['pickup'] : null;
    $distance = isset($_REQUEST['distance']) ? floatval($_REQUEST['distance']) : 0;
    $date = isset($_REQUEST['date']) ? $_REQUEST['date'] : null;
    $time = isset($_REQUEST['time']) ? $_REQUEST['time'] : null;
    $userTenantId = $_SESSION['user_tenant_id'];
    $pickuplatlon = isset($_REQUEST['pickuplonlat']) ? $_REQUEST['pickuplonlat'] : null;
    $dropofflatlon = isset($_REQUEST['dropofflonlat']) ? $_REQUEST['dropofflonlat'] : null;


    // Ensure required fields are provided
    if (!$drop || !$carType || !$pickup || !$distance || !$date || !$userTenantId) {
        echo "Required data missing.";
        exit;
    }
// Function to check if a point (lat, lon) is inside a polygon
function isPointInPolygon($point, $polygon) {
    $inside = false;
    $x = $point['lat'];
    $y = $point['lng'];
    $n = count($polygon);

    for ($i = 0, $j = $n - 1; $i < $n; $j = $i++) {
        $xi = $polygon[$i]['lat'];
        $yi = $polygon[$i]['lng'];
        $xj = $polygon[$j]['lat'];
        $yj = $polygon[$j]['lng'];

        $intersect = (($yi > $y) != ($yj > $y)) &&
            ($x < ($xj - $xi) * ($y - $yi) / ($yj - $yi) + $xi);
        if ($intersect) $inside = !$inside;
    }

    return $inside;
}

// Function to check if pickup and drop-off are within plots
function isWithinPlot($pickupLat, $pickupLon, $dropLat, $dropLon, $plotData) {
    foreach ($plotData as $plot) {
        $plotFromCoords = json_decode($plot['plot_from'], true); // Decode plot_from coordinates
        $plotToCoords = json_decode($plot['plot_to'], true); // Decode plot_to coordinates

        // Check if pickup is in plot_from and drop-off is in plot_to
        $pickupInPlot = isPointInPolygon(['lat' => $pickupLat, 'lng' => $pickupLon], $plotFromCoords);
        $dropInPlot = isPointInPolygon(['lat' => $dropLat, 'lng' => $dropLon], $plotToCoords);

        if ($pickupInPlot && $dropInPlot) {
            return $plot['price_per_hour']; // Return price if both match
        }
    }
    return null;
}

// Step 1: Fetch all plots
$plotQuery = "SELECT plot_from, plot_to, price_per_hour FROM hourly_rate WHERE car_type = ? AND user_tenant_id = ?";
$plotStmt = mysqli_prepare($con, $plotQuery);

if ($plotStmt) {
    mysqli_stmt_bind_param($plotStmt, "ss", $carType, $userTenantId);
    mysqli_stmt_execute($plotStmt);
    $plotResult = mysqli_stmt_get_result($plotStmt);

    $plotData = [];
    while ($row = mysqli_fetch_assoc($plotResult)) {
        $plotData[] = $row;
    }

    if ($pickuplatlon && $dropofflatlon) {
        list($pickupLat, $pickupLon) = explode(",", $pickuplatlon);
        list($dropLat, $dropLon) = explode(",", $dropofflatlon);

        // Step 2: Check if pickup and drop-off coordinates are within a plot
        $plotFare = isWithinPlot($pickupLat, $pickupLon, $dropLat, $dropLon, $plotData);

        if ($plotFare !== null) {
            // If coordinates match, use fare from the plot table
            echo number_format($plotFare, 2);
            exit;
        }
    }
}

    function extractPostcode($address) {
    // Regular expression to extract postcode
    if (preg_match('/\b[A-Z]{1,2}[0-9][A-Z0-9]? ?[0-9][A-Z]{2}\b/i', $address, $matches)) {
        return strtoupper($matches[0]); // Return the postcode in uppercase
    }
    return null;
}
$pickupPostcode = extractPostcode($pickup);
$dropoffPostcode = extractPostcode($dropoff);

    $fixedPriceQuery = "SELECT price FROM fixed_rate WHERE pick_up = ? AND `drop_off` = ? AND car_type = ? AND user_tenant_id = ? ";
    $fixedPriceStmt = mysqli_prepare($con, $fixedPriceQuery);

    if ($fixedPriceStmt) {
        mysqli_stmt_bind_param($fixedPriceStmt, "ssss", $pickup, $drop, $carType, $userTenantId);
        mysqli_stmt_execute($fixedPriceStmt);
        $fixedPriceResult = mysqli_stmt_get_result($fixedPriceStmt);

        if (mysqli_num_rows($fixedPriceResult) > 0) {
            $fixedPriceRow = mysqli_fetch_assoc($fixedPriceResult);
            $fixedPrice = $fixedPriceRow['price'];

            echo number_format($fixedPrice);
        } else {
    $query = "SELECT * FROM fare_amount WHERE car_type = ? AND miles_from <= ? AND miles_to >= ? AND user_tenant_id = ?";
    $stmt = mysqli_prepare($con, $query);

    if ($stmt) {
        mysqli_stmt_bind_param($stmt, "sdds", $carType, $distance, $distance, $userTenantId);
        mysqli_stmt_execute($stmt);
        $result = mysqli_stmt_get_result($stmt);

        if (mysqli_num_rows($result) > 0) {
            $row = mysqli_fetch_assoc($result);
            $firstMilePrice = $row['first_mile_price'];
            $perMilePrice = $row['per_mile_price'];

            // Calculate the total fare
            $totalFare = $firstMilePrice + ($distance - 1) * $perMilePrice;

            // Check for congestion charge
            if ($pickupPostcode || $dropoffPostcode) {
                $zoneQuery = "SELECT post_code FROM congestion_postcode 
                              WHERE (LOWER(post_code) = LOWER(?) OR LOWER(post_code) = LOWER(?)) ";
                $zoneStmt = mysqli_prepare($con, $zoneQuery);

                if ($zoneStmt) {
                    mysqli_stmt_bind_param($zoneStmt, "ss", $pickupPostcode, $dropoffPostcode);
                    mysqli_stmt_execute($zoneStmt);
                    $zoneResult = mysqli_stmt_get_result($zoneStmt);

                    // If a matching postcode is found, add 15 to the total fare
                    if (mysqli_num_rows($zoneResult) > 0) {
                        $totalFare += 15;
                    }
                }
            }

            // Query to get the percentage based on date range and time
            $percentageQuery = "SELECT * FROM sugar_amount WHERE 
                                (? BETWEEN from_date AND till_date) OR 
                                (? BETWEEN from_time AND till_time) 
                                AND user_tenant_id = ?";
            $percentageStmt = mysqli_prepare($con, $percentageQuery);

            if ($percentageStmt) {
                mysqli_stmt_bind_param($percentageStmt, "sss", $date, $time, $userTenantId);
                mysqli_stmt_execute($percentageStmt);
                $percentageResult = mysqli_stmt_get_result($percentageStmt);

                if (mysqli_num_rows($percentageResult) > 0) {
                    $percentageRow = mysqli_fetch_assoc($percentageResult);
                    $percentage = $percentageRow['type'];
                    $rate = $percentageRow['rate'];

                    if ($percentage == 'Percent') {
                        $additionalFare = ($totalFare * $rate) / 100;
                        $totalFare += $additionalFare;
                    } elseif ($percentage == 'Amount') {
                        $totalFare += $rate;
                    }
                }
            }

            // Output the total fare
            echo number_format($totalFare, 2);
        } else {
            echo "No fare information found.";
        }
    } else {
        echo "Error in the database query: " . mysqli_error($con);
    }
    }

    } else {
        echo "Error in preparing the query: " . mysqli_error($con);
    }
} else {
    echo "No data submitted.";
}
?>
