<?php
include("../db/db.php");

header('Content-Type: application/json');

// Enable error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);


$yayFile = 'call_data.json';
$aoneFile = 'call_data_Aone.json';

// Start session to get user tenant ID
session_start();
if (!isset($_SESSION['user_tenant_id'])) {
    echo json_encode(['status' => 'error', 'message' => 'User tenant ID not found']);
    exit;
}

// Get user_tenant_id from session
$userTenantId = $_SESSION['user_tenant_id'];

// Determine which file to process based on user_tenant_id
$filename = ($userTenantId === 'af_159682') ? $aoneFile : (($userTenantId === 'ae_145698') ? $yayFile : null);

// Handle invalid user_tenant_id
if ($filename === null) {
    echo json_encode(['status' => 'error', 'message' => 'Invalid user tenant ID']);
    exit;
}

// Check if the selected file exists and is not empty
if (file_exists($filename) && filesize($filename) > 0) {
    $callData = file_get_contents($filename);

    // Decode the call data JSON
    $data = json_decode($callData, true);
    if (json_last_error() === JSON_ERROR_NONE) {
        // Iterate over the calls and normalize the caller field
        foreach ($data as &$call) {
            // Normalize the caller field (Yay.com: 'from', AOne: 'phoneno')
            $caller = isset($call['phoneno']) ? $call['phoneno'] : (isset($call['from']) ? $call['from'] : 'Unknown');

            $stmt = $con->prepare("SELECT name FROM bookins WHERE phone = ?");
            if ($stmt === false) {
                echo json_encode(['status' => 'error', 'message' => 'Database prepare failed: ' . $con->error]);
                exit;
            }

            $stmt->bind_param("s", $caller);
            if (!$stmt->execute()) {
                echo json_encode(['status' => 'error', 'message' => 'Database execute failed: ' . $stmt->error]);
                exit;
            }

            $stmt->bind_result($customerName);
            if (!$stmt->fetch()) {
                $customerName = 'Unknown'; // Default if no match is found
            }

            // Close the statement
            $stmt->close();

            // Add normalized fields to the call data
            $call['caller'] = $caller; // Add normalized caller field
            $call['name'] = $customerName; // Add customer name
        }

        // Output the processed call data
        echo json_encode(['status' => 'success', 'calls' => $data]);
    } else {
        // Handle invalid JSON data
        echo json_encode(['status' => 'error', 'message' => 'Invalid JSON data']);
    }
} else {
    // Handle missing or empty file
    echo json_encode(['status' => 'no_data', 'message' => 'No call data available']);
}

// Close the database connection
$con->close();
?>
