<?php
header('Content-Type: application/json');

// Enable error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Start session to get user tenant ID
session_start();
if (!isset($_SESSION['user_tenant_id'])) {
    echo json_encode(['status' => 'error', 'message' => 'User tenant ID not found']);
    exit;
}

// Get `user_tenant_id` from session
$userTenantId = $_SESSION['user_tenant_id'];

// Determine which file to process based on `user_tenant_id`
$filename = ($userTenantId === 'af_159682') ? './call_log_aOne.txt' : (($userTenantId === 'ae_145698') ? './call_log.txt' : null);

// Handle invalid `user_tenant_id`
if ($filename === null) {
    echo json_encode(['status' => 'error', 'message' => 'Invalid user tenant ID']);
    exit;
}

// Check if the selected file exists and is not empty
if (!file_exists($filename) || filesize($filename) === 0) {
    echo json_encode(['status' => 'no_data', 'message' => 'No call history available']);
    exit;
}

// Read file contents
$file_contents = file_get_contents($filename);

// Match log entries in the file
preg_match_all('/\[(.*?)\] => (.*?)\s*(?=\[|$)/', $file_contents, $matches);

// Initialize an array to store the parsed log entries
$call_logs = [];
$current_entry = [];

// Parse log entries without relying on `uuid`
foreach ($matches[1] as $index => $key) {
    $current_entry[trim($key)] = trim($matches[2][$index]);

    // Check if the entry has the required fields to determine it's complete
    if (
        ($userTenantId === 'af_159682' && isset($current_entry['timestamp'], $current_entry['phoneno'])) ||
        ($userTenantId !== 'af_159682' && isset($current_entry['start'], $current_entry['from']))
    ) {
        $call_logs[] = $current_entry;
        $current_entry = [];
    }
}

// Normalize data and filter call history based on fields
$filtered_calls = [];
foreach ($call_logs as $log) {
    if ($userTenantId === 'af_159682') { // For `call_log_Aone.txt`
        $timestampField = 'timestamp';
        $callerField = 'phoneno';
    } else { // For `call_log.txt`
        $timestampField = 'start';
        $callerField = 'from';
    }

    if (isset($log[$timestampField]) && isset($log[$callerField])) {
        // Add the call data to filtered calls
        $filtered_calls[] = [
            'timestamp' => $log[$timestampField], // Convert to Unix timestamp
            'caller' => $log[$callerField]
        ];
    }
}

// Response
$response = [
    "status" => "success",
    "calls" => $filtered_calls
];

echo json_encode($response);
?>
