<?php
session_start();
include("../db/db.php");

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

try {
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        // Fetch JSON input
        $input = file_get_contents("php://input");
        $data = json_decode($input, true);

        // Validate JSON input
        if ($data === null && json_last_error() !== JSON_ERROR_NONE) {
            http_response_code(400);
            echo json_encode(['success' => false, 'message' => 'Invalid JSON input.']);
            exit;
        }

        // Extract driver_id and new_position from JSON data
        $driver_id = isset($data['driver_id']) ? $data['driver_id'] : null;
        $new_position = isset($data['new_position']) ? (int)$data['new_position'] : null;
        $user_id = $_SESSION['user_tenant_id'];

        if ($driver_id === null || $new_position === null) {
            http_response_code(400); // Bad Request
            echo json_encode(['success' => false, 'message' => 'Missing driver_id or new_position.']);
            exit;
        }

        // Fetch the current position of the driver
        $query = "SELECT position FROM drivers WHERE Driver_id = ? AND user_tenant_id = ?";
        $stmt = $con->prepare($query);
        if (!$stmt) {
            http_response_code(500); // Internal Server Error
            echo json_encode(['success' => false, 'message' => 'Failed to prepare statement.']);
            exit;
        }
        $stmt->bind_param("is", $driver_id, $user_id);
        if (!$stmt->execute()) {
            http_response_code(500);
            echo json_encode(['success' => false, 'message' => 'Failed to execute query.']);
            exit;
        }
        $stmt->bind_result($current_position);
        if (!$stmt->fetch()) {
            http_response_code(404); // Not Found
            echo json_encode(['success' => false, 'message' => 'Driver ID not found.']);
            $stmt->close();
            exit;
        }
        $stmt->close();

        // Update other drivers' positions if necessary
        if ($new_position > $current_position) {
            // Decrement positions for drivers between the current and new positions
            $query = "UPDATE drivers 
                      SET position = position - 1 
                      WHERE position > ? AND position <= ? AND user_tenant_id = ?";
            $stmt = $con->prepare($query);
            $stmt->bind_param("iis", $current_position, $new_position, $user_id);
            $stmt->execute();
        } elseif ($new_position < $current_position) {
            // Increment positions for drivers between the new and current positions
            $query = "UPDATE drivers 
                      SET position = position + 1
                      WHERE position >= ? AND position < ? AND user_tenant_id = ?";
            $stmt = $con->prepare($query);
            $stmt->bind_param("iis", $new_position, $current_position, $user_id);
            $stmt->execute();
        }

        // Update the selected driver's position
        $query = "UPDATE drivers SET position = ? WHERE Driver_id = ? AND user_tenant_id = ?";
        $stmt = $con->prepare($query);
        $stmt->bind_param("iis", $new_position, $driver_id, $user_id);
        if ($stmt->execute()) {
            echo json_encode(['success' => true, 'message' => 'Position updated successfully.']);
        } else {
            http_response_code(500);
            echo json_encode(['success' => false, 'message' => 'Failed to update driver position.']);
        }
    } else {
        http_response_code(405); // Method Not Allowed
        echo json_encode(['success' => false, 'message' => 'Invalid request method.']);
    }
} catch (Exception $e) {
    error_log("Exception: " . $e->getMessage());
    http_response_code(500); // Internal Server Error
    echo json_encode(['success' => false, 'message' => $e->getMessage()]);
    exit;
}
?>
