<?php
include("../db/db.php");

header("Content-Type: application/json");

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
 
    $data = json_decode(file_get_contents('php://input'), true);

    $driver_id = isset($data['driver_id']) ? $data['driver_id'] : null;
    $break_status = isset($data['break_status']) ? $data['break_status'] : null;
    $user_id = isset($data['user_tenant_id']) ? $data['user_tenant_id'] : null;

    // Validate driver_id
    if (!$driver_id || !is_numeric($driver_id)) {
        echo json_encode([
            'status' => 'error',
            'message' => 'Driver ID is required and must be a valid number.'
        ]);
        exit;
    }

    // Validate user_tenant_id
    if (!$user_id) {
        echo json_encode([
            'status' => 'error',
            'message' => 'Company ID is required.'
        ]);
        exit;
    }

    // Validate break_status
    if ($break_status === null || ($break_status != '1' && $break_status != '0')) {
        echo json_encode([
            'status' => 'error',
            'message' => 'Break status must be 1 (on break) or 0 (not on break).'
        ]);
        exit;
    }

    // Check if the driver exists in the database
    try {
        $checkStmt = $con->prepare("SELECT 1 FROM drivers WHERE driver_id = ? AND user_tenant_id = ?");
        $checkStmt->bind_param("is", $driver_id, $user_id);
        $checkStmt->execute();
        $checkStmt->store_result();

        if ($checkStmt->num_rows == 0) {
            echo json_encode([
                'status' => 'error',
                'message' => 'Driver not found or does not belong to the specified company.'
            ]);
            $checkStmt->close();
            exit;
        }

   
        $stmt = $con->prepare("UPDATE drivers SET Break_status = ? WHERE driver_id = ? AND user_tenant_id = ?");
        $stmt->bind_param("iis", $break_status, $driver_id, $user_id);

        if ($stmt->execute()) {
            echo json_encode([
                'status' => 'success',
                'message' => 'Break status updated successfully.'
            ]);
        } else {
            echo json_encode([
                'status' => 'error',
                'message' => 'Failed to update break status. Please try again.'
            ]);
        }

        $stmt->close();
        $checkStmt->close();
    } catch (Exception $e) {
        echo json_encode([
            'status' => 'error',
            'message' => 'An error occurred: ' . $e->getMessage()
        ]);
    }
} else {
    echo json_encode([
        'status' => 'error',
        'message' => 'Invalid request method. Please use POST.'
    ]);
}
