<?php

include '../db/db.php'; 

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode([
        "status" => "error",
        "message" => "Invalid request method. Please use POST."
    ]);
    exit;
}

$input = json_decode(file_get_contents('php://input'), true);

if (!isset($input['driver_id']) || empty($input['driver_id']) || !isset($input['user_tenant_id']) || empty($input['user_tenant_id'])) {
    echo json_encode([
        "status" => "error",
        "message" => "Driver ID and Tenant ID are required."
    ]);
    exit;
}

$driverId = $input['driver_id'];
$tenantId = $input['user_tenant_id'];


$sql = "SELECT 
            Driver_image AS driver_image,
            License_Image AS driver_license_image,
            Vehicle_Image AS vehicle_image,
            pco_image AS driver_pco_image,
            ina_image AS driver_insurance_image,
            veh_pco_image AS vehicle_pco_image,
            mot_image AS mot_image,
            road_image AS road_image,
            veh_ins_image AS vehicle_insurance_image
        FROM drivers
        WHERE Driver_id = ? AND user_tenant_id = ?";

$stmt = $con->prepare($sql);
$stmt->bind_param("is", $driverId, $tenantId); 
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $row = $result->fetch_assoc();
    
    echo json_encode([
        "status" => "success",
        "data" => [
            "driver_image" => $row['driver_image'],
            "driver_license_image" => $row['driver_license_image'],
            "vehicle_image" => $row['vehicle_image'],
            "driver_pco_image" => $row['driver_pco_image'],
            "driver_insurance_image" => $row['driver_insurance_image'],
            "vehicle_pco_image" => $row['vehicle_pco_image'],
            "mot_image" => $row['mot_image'],
            "road_image" => $row['road_image'],
            "vehicle_insurance_image" => $row['vehicle_insurance_image']
        ]
    ]);
} else {
    echo json_encode([
        "status" => "error",
        "message" => "No images found for the provided Driver ID and Tenant ID."
    ]);
}
$stmt->close();
$con->close();
?>
