<?php
include("../db/db.php");

header('Content-Type: application/json');

// Read raw JSON data from the request body for POST requests
$input = file_get_contents('php://input');
$data = json_decode($input, true);

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Check if the data is valid
    if (isset($data['job_id']) && isset($data['start']) && isset($data['user_tenant_id'])) {
        $jobId = $data['job_id'];
        $accepted = $data['start'];
        $user_id = $data['user_tenant_id'];
    } else {
        $response = array('success' => false, 'message' => 'Please provide all required parameters: id and user_tenant_id');
        echo json_encode($response);
        exit;
    }

    if ($accepted !== null) {
        if ($jobId !== null) {
            // Set the timezone to London
            date_default_timezone_set('Europe/London');
            $currentTime = date('d-m-Y H:i');
            $query = $con->prepare("UPDATE bookins SET accepted = ? WHERE id = ? AND user_tenant_id = ? ");
            $query->bind_param('sis', $accepted, $jobId, $user_id);
            $result = $query->execute();

            if ($result) {
                if ($accepted == '1') {
                    $dispatchQuery = $con->prepare("SELECT dispatch_DriverId FROM bookins WHERE id = ? AND user_tenant_id = ?");
                    $dispatchQuery->bind_param('is', $jobId, $user_id);
                    $dispatchQuery->execute();
                    $dispatchResult = $dispatchQuery->get_result();

                    if ($dispatchResult && $dispatchResult->num_rows > 0) {
                        $row = $dispatchResult->fetch_assoc();
                        $driverId = $row['dispatch_DriverId'];
                        // Update the status of the driver to "unplot"
                        $updateDriverQuery = $con->prepare("UPDATE drivers SET plot = 'unplot' WHERE Driver_id = ? AND user_tenant_id = ? ");
                        $updateDriverQuery->bind_param('is', $driverId, $user_id);
                        $updateDriverResult = $updateDriverQuery->execute();
                         $response = array('success' => true, 'message' => 'Job Started');

                    } else {
                        $response = array('success' => false, 'message' => 'Driver not found');
                    }
                } elseif ($accepted == '0') {
                    // Assuming $driverId should be fetched similarly to acceptance case
                    $dispatchQuery = $con->prepare("SELECT dispatch_DriverId FROM bookins WHERE id = ?");
                    $dispatchQuery->bind_param('i', $jobId);
                    $dispatchQuery->execute();
                    $dispatchResult = $dispatchQuery->get_result();

                    if ($dispatchResult && $dispatchResult->num_rows > 0) {
                        $row = $dispatchResult->fetch_assoc();
                        $driverId = $row['dispatch_DriverId'];
                        $queryReject = $con->prepare("UPDATE bookins SET allocate_DriverId = CONCAT(?, '-Reject'), dispatch_DriverId = '' WHERE id = ? AND user_tenant_id= ? ");
                        $queryReject->bind_param('sis', $driverId, $jobId, $user_id);
                        $result = $queryReject->execute();
                        if ($result) {
                            $response = array('success' => true, 'message' => 'Job rejected');
                        } else {
                            $response = array('success' => false, 'message' => 'Failed to reject job');
                        }
                    } else {
                        $response = array('success' => false, 'message' => 'Driver not found for rejection');
                    }
                }
            } else {
                $response = array('success' => false, 'message' => 'Error accepting/rejecting job: ' . $con->error);
            }
        } else {
            $response = array('success' => false, 'message' => 'Missing parameter');
        }
    } else {
        $response = array('success' => false, 'message' => 'Invalid parameter');
    }
} else {
    $response = array('success' => false, 'message' => 'Invalid request method');
}

echo json_encode($response);

mysqli_close($con);

?>
